@@ -22,6 +22,9 @@
 // ---------------------------------------------------------------------------
 Target::Target()
 {
+	name = "";
+	groupName = "";
+	type = "";
 	id = 0;
 	pictureSmall = NULL;
 	picture = NULL;
@@ -129,6 +132,13 @@ DatabaseManager::DatabaseManager(QObject *parent) :
 
 DatabaseManager::~DatabaseManager()
 {
+//	QString path(QDir::home().path());
+//	path.append(QDir::separator()).append("BACKqtwallet.db.sqlite");
+//	path = QDir::toNativeSeparators(path);
+//	//db.setDatabaseName(path);
+//
+//	QSqlDatabase::cloneDatabase(db, path);
+
 	qDebug () << "CLOSE DB";
 	if (db.isOpen()) {
 		qDebug () << "CLOSing DB";
@@ -138,7 +148,10 @@ DatabaseManager::~DatabaseManager()
 
 bool DatabaseManager::isInit()
 {
-	return db.tables().count() == 3;
+	qDebug () << "is init?";
+
+
+	return db.tables().count() >= 3;
 }
 
 bool DatabaseManager::initDB()
@@ -150,11 +163,59 @@ bool DatabaseManager::initDB()
 	if (createIdTable()) {
 		createTargetTable();
 		createTargetFieldTable();
+		createTableVersion ();
 	}
 
 	// Check that tables exists
-	if (db.tables().count() != 3)
-		ret = false;
+			if (db.tables().count() != 4)
+				ret = false;
+
+	return ret;
+}
+
+//bool copyFile(QString oldFilePath, QString newFilePath)
+//{
+//  //same file, no need to copy
+//  if(oldFilePath.compare(newFilePath) == 0)
+//    return true;
+//
+//  //load both files
+//  QFile oldFile(oldFilePath);
+//  QFile newFile(newFilePath);
+//  bool openOld = oldFile.open( IO_ReadOnly );
+//  bool openNew = newFile.open( IO_WriteOnly );
+//
+//  //if either file fails to open bail
+//  if(!openOld || !openNew) { return false; }
+//
+//  //copy contents
+//  uint BUFFER_SIZE = 16000;
+//  char* buffer = new char[BUFFER_SIZE];
+//  while(!oldFile.atEnd())
+//  {
+//    Q_ULONG len = oldFile.readBlock( buffer, BUFFER_SIZE );
+//    newFile.writeBlock( buffer, len );
+//  }
+//
+//  //deallocate buffer
+//  delete[] buffer;
+//  buffer = NULL;
+//  return true;
+//}
+
+bool DatabaseManager::migrateVersion (int fromV, int toV) {
+	bool ret = false;
+
+	qDebug () << "MIGRATING DB VERSION FROM " << fromV << " TO " << toV;
+
+	if (fromV == 0 && toV == 1) {
+		backupDB ();
+
+		QSqlQuery query;
+		ret = query.exec("alter table targets ADD COLUMN groupName varchar(100)");
+	}
+
+	qDebug () << "MIGRATED DB VERSION FROM " << fromV << " TO " << toV << " WITH RESULT " << ret;
 
 	return ret;
 }
@@ -170,7 +231,22 @@ bool DatabaseManager::deleteDB()
 
 	return QFile::remove(path);
 }
+bool DatabaseManager::backupDB() {
+	QString path(QDir::home().path());
+	path.append(QDir::separator()).append("qtwallet.db.sqlite");
+	path = QDir::toNativeSeparators(path);
 
+	QString pathBack(QDir::home().path());
+	pathBack.append(QDir::separator()).append("BACKqtwallet.db.sqlite");
+	pathBack = QDir::toNativeSeparators(pathBack);
+
+	QFile file (path);
+	bool dup = file.copy(pathBack);
+
+	qDebug () << "duplicate DB " << dup;
+
+	return dup;
+}
 bool DatabaseManager::openDB()
 {
 	qDebug () << "OPEN DB";
@@ -181,10 +257,20 @@ bool DatabaseManager::openDB()
 	QString path(QDir::home().path());
 	path.append(QDir::separator()).append("qtwallet.db.sqlite");
 	path = QDir::toNativeSeparators(path);
+
 	db.setDatabaseName(path);
 
 	// Open databasee
-	return db.open();
+	if (db.open()) {
+		// Check that tables exists
+		if (db.tables().count() == 3) {
+			migrateVersion (0, 1);
+			return createTableVersion ();
+		}
+
+		return true;
+	}
+	return false;
 }
 
 QSqlError DatabaseManager::lastError()
@@ -203,6 +289,24 @@ bool DatabaseManager::createIdTable()
 	return ret;
 }
 
+bool DatabaseManager::createTableVersion()
+{
+	// Create table
+	bool ret = false;
+	if (db.isOpen()) {
+		QSqlQuery query;
+		ret = query.exec("create table softwareVersion (versionNumber integer)");
+		if (ret) {
+			ret = query.prepare("insert into softwareVersion values (:ver)");
+			if (ret) {
+				query.bindValue(":ver", SOFT_VERSION);
+				ret = query.exec();
+			}
+		}
+	}
+	return ret;
+}
+
 int DatabaseManager::nextId()
 {
 	int ret = -1;
@@ -234,6 +338,7 @@ void DatabaseManager::reset () {
 		ret |= query.exec("drop table id");
 		ret |= query.exec("drop table targets");
 		ret |= query.exec("drop table fieds");
+		ret |= query.exec("drop table softwareVersion");
 	}
 
 }
@@ -260,7 +365,7 @@ bool DatabaseManager::openDB(QString pas) {
 	if (!opendb) return false;
 
 	qDebug() << "init db with pas";
-	
+
 	if (isInit ()) {
 		if (hasSecretPhrase()) {
 			initdb = checkPassword(pas);
@@ -273,6 +378,9 @@ bool DatabaseManager::openDB(QString pas) {
 		if (initDB())
 			initdb = createPassword(pas);
 	}
+
+	qDebug() << "init db with pas " << initdb;
+
 	return initdb;
 }
 
@@ -282,6 +390,8 @@ bool DatabaseManager::isReady () {
 
 bool DatabaseManager::checkPassword (QString _a)
 {
+	qDebug () << "checkPassword "; // << _a;
+
 	QByteArray t = _a.toLocal8Bit();
 	
 	keyLen = 32*8;
@@ -309,6 +419,8 @@ bool DatabaseManager::checkPassword (QString _a)
 
 bool DatabaseManager::createPassword (QString _a)
 {
+	qDebug () << "createPassword";
+
 	QByteArray t = _a.toLocal8Bit();
 	
 	keyLen = 32*8;
@@ -352,7 +464,7 @@ bool DatabaseManager::updateSecretPhrase(QByteArray a) {
 
 bool DatabaseManager::hasSecretPhrase()
 {
-	//qDebug () << "has secret?";
+	qDebug () << "has secret?";
 	
 	QSqlQuery query("select phrase from id");
 	if (query.next()) {
@@ -364,7 +476,7 @@ bool DatabaseManager::hasSecretPhrase()
 
 QByteArray DatabaseManager::selectSecretPhrase()
 {
-	//qDebug () << "get secret?";
+	qDebug () << "get secret?";
 
 	QByteArray ret;
 	QSqlQuery query("select phrase from id");
@@ -386,7 +498,7 @@ bool DatabaseManager::createTargetTable()
 		                 "name varchar(30), "
 		                 "picture BLOB, "
 		                 "pictureBack BLOB, "
-		                 "type varchar(5))");
+		                 "type varchar(5), groupName varchar(100))");
 
 	}
 	return ret;
@@ -514,7 +626,7 @@ bool DatabaseManager::insertTarget(Target* target)
 		// http://www.sqlite.org/autoinc.html
 		// NULL = is the keyword for the autoincrement to generate next value
 		QSqlQuery query;
-		ret = query.prepare("INSERT INTO targets (name, type, picture, pictureBack) VALUES (:name, :type, :picture, :pictureBack)");
+		ret = query.prepare("INSERT INTO targets (name, type, picture, pictureBack, groupName) VALUES (:name, :type, :picture, :pictureBack, :groupName)");
 		QByteArray t1;
 
 		//qDebug() << "step 1" ;
@@ -524,6 +636,7 @@ bool DatabaseManager::insertTarget(Target* target)
 		//qDebug() << "step 3" ;
 			query.bindValue(":name", t1);
 			query.bindValue(":type", target->type);
+			query.bindValue(":groupName", target->groupName);
 					//qDebug() << "step 4" ;
 
 			QByteArray im1;
@@ -572,13 +685,14 @@ QList<Target*> DatabaseManager::getTargets(QString filter)
 {
 	QList<Target*> result;
 
-	QSqlQuery query("select id, name, type from targets");
+	QSqlQuery query("select id, name, type, groupName from targets");
 	//QSqlQuery query("select id, name, type, picture, pictureBack  from targets");
 	while (query.next()) {
 		Target * item = new Target();
 		item->id = query.value(0).toInt();
 		decrypt(query.value(1).toByteArray(), item->name);
 		item->type = query.value(2).toString();
+		item->groupName = query.value(3).toString();
 		item->pictureSmall = NULL;
 		item->picture = NULL;
 		item->pictureBack = NULL;
@@ -668,12 +782,13 @@ bool DatabaseManager::updateTarget(Target* target)
 	bool ret = false;
 	if (db.isOpen()) {
 		QSqlQuery query;
-		ret = query.prepare("UPDATE targets set name=:name, type=:type where id=:code");
+		ret = query.prepare("UPDATE targets set name=:name, type=:type, groupName=:groupName where id=:code");
 		QByteArray t1;
 		if (ret) {
 			encrypt(target->name, t1);
 			query.bindValue(":name", t1);
 			query.bindValue(":type", target->type);
+			query.bindValue(":groupName", target->groupName);
 			query.bindValue(":code", target->id);
 			ret = query.exec();
 
