@@ -53,6 +53,7 @@ public:
 	~Target();
 	int id;
 	QString name;
+	QString groupName;
 	QString type;
 
 	QImage * getPictureSmall ();
@@ -74,6 +75,8 @@ public:
 	QImage * pictureBack;
 
 	QList<TargetField*> fields; // ?? * or not
+
+	bool listLoaded;
 };
 
 
@@ -88,12 +91,14 @@ public:
 	~DatabaseManager();
 
 public:
+	//bool sortTargets (const Target * f, const Target * g);
+
 	bool openDB(QString pass);
 	bool deleteDB();
-	bool checkPassword (QString a);
-	bool createPassword (QString a);
+	bool hasPassword ();
 	bool isReady ();
 	void lock ();
+	void reset ();
 	
 	int nextId();
 
@@ -115,15 +120,23 @@ public:
 	QImage * getPicture (Target * t);
 	QImage * getPictureBack (Target * t);
 
+	bool backupDB();
+
 private:
 	bool openDB();
 	bool initDB();
 	bool isInit();
 
+	bool checkPassword (QString a);
+	bool createPassword (QString a);
+
 	bool createTargetTable();
 	bool createIdTable();
 	bool createTargetFieldTable();
 
+	bool createTableVersion ();
+	bool migrateVersion (int fromV, int toV);
+
 	void encrypt (const QString a, QByteArray& b);
 	void decrypt (const QByteArray& a, QString& b);
 
