@@ -37,26 +37,44 @@ protected:
     }
 };
 
-DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidget *parent) :
+DetailWindow::DetailWindow(Target * _target, bool istemplate, bool edit, eWallet *paTarget, QWidget *parent) :
 		QMainWindow(parent)
 {
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 	if (!edit)
 		connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
 
-	isNew = target == NULL;
+	isNew = istemplate || _target == NULL;
 
-	this->target = target;
+	this->target = _target;
 	this->parent = paTarget;
 	this->edit = edit;
 
+	if (istemplate) {
+		this->target = new Target ();
+		this->target->type = _target->type;
+		this->target->groupName = _target->groupName;
+
+		for (int i = 0; i < _target->fields.size(); i++) {
+			TargetField * tmp = _target->fields.at(i);
+
+			//if (!target->existField (tmp.name)) {
+				TargetField * f=  new TargetField (tmp->name, tmp->type, tmp->encrypted, tmp->order);
+
+				this->target->fields.append(f);
+			//}
+		}
+
+		_target->freeFieldList();
+	}
+	else
 	if (isNew) {
 		this->target = new Target ();
 		this->target->type = this->parent->types[0];
 		changeFields (0);
 	}
 
-	qDebug () << " going to " << edit << " " << (isNew ? "NEW" : target->name);
+	qDebug () << " going to " << edit << " " << (isNew ? "NEW" : this->target->name);
 
 	orgType = this->target->type;
 
@@ -66,9 +84,9 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 	currentImageN = NULL;
 	currentImageBackN = NULL;
 
-	if (target) {
-		currentImage = target->getPicture();
-		currentImageBack = target->getPictureBack();
+	if (_target && !istemplate) {
+		currentImage = this->target->getPicture();
+		currentImageBack = this->target->getPictureBack();
 	}
 	else {
 		currentImage = NULL;
@@ -126,26 +144,34 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 
 	    nameLineEdit = new QLineEdit(this);
 		componentLayout->addWidget(nameLineEdit, 1, 3, 1, 4);
-		if (target)
-			nameLineEdit->setText (target->name);
+
+			nameLineEdit->setText (this->target->name);
+
+		nameLabel = new QLabel("Group Name", this);
+		componentLayout->addWidget(nameLabel, 2, 1, 1, 2);
+
+	    groupLineEdit = new QLineEdit(this);
+		componentLayout->addWidget(groupLineEdit, 2, 3, 1, 4);
+
+			groupLineEdit->setText (this->target->groupName);
 	}
 	else {
-		this->setWindowTitle (target->name);
+		this->setWindowTitle (_target->name);
 	}
 
 	if (edit) {
 		// type label
 		QLabel * typeLabel = new QLabel("Type", this);
 
-		componentLayout->addWidget(typeLabel, 2, 1, 1, 2);
+		componentLayout->addWidget(typeLabel, 3, 1, 1, 2);
 
 		typeLineEdit = new QComboBox(this);
 
 		bool selected = false;
 		for(int i = 0; i < this->parent->types.size(); i++) {
 			typeLineEdit->addItem (this->parent->types[i], this->parent->types[i]);
-			if (target)
-				if (target->type == this->parent->types[i]) {
+
+				if (this->target->type == this->parent->types[i]) {
 					typeLineEdit->setCurrentIndex(i);
 					selected = true;
 				}
@@ -156,7 +182,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 
 	    connect(typeLineEdit, SIGNAL(activated(int)), this, SLOT(emitCommitData(int)));
 
-		componentLayout->addWidget(typeLineEdit, 2, 3, 1, 4);
+		componentLayout->addWidget(typeLineEdit, 3, 3, 1, 4);
 	}
 	else {
 
@@ -168,7 +194,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 
 	QObject::connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(cardMenu(const QPoint&)));
 
-	if (edit || target->getPicture() != NULL) {
+	if (edit || this->target->getPicture() != NULL) {
 		imageLabel = new QLabel(this);
 
 		imageLabel->setBackgroundRole(QPalette::NoRole);
@@ -204,7 +230,7 @@ DetailWindow::DetailWindow(Target * target, bool edit, eWallet *paTarget, QWidge
 		imageLabel = NULL;
 	}
 
-	if (edit || target->getPictureBack() != NULL) {
+	if (edit || this->target->getPictureBack() != NULL) {
 		imageBackLabel = new QLabel(this);
 
 		imageBackLabel->setBackgroundRole(QPalette::NoRole);
@@ -485,6 +511,7 @@ void DetailWindow::saveTarget () {
 
 
 	this->target->name = nameLineEdit->text();
+	this->target->groupName = groupLineEdit->text();
 	this->target->type = typeLineEdit->itemData(typeLineEdit->currentIndex()).toString();
 	
 	//qDebug () << "getting fields ";
