@@ -5,12 +5,6 @@
 // TODO export to a file with pictures!!!??
 // TODO import picture from camera
 // TODO modify picture (zoom, ...)
-// TODO support for portrain
-// TODO final images
- * TODO strong encryption with characters
- * TODO check that export images get the right size
- * TODO image size when no credit card (axa)
- * TODO free list resources
  * TODO after change type it is not refreshed on list
  * TODO implements copy of information field (and images?)
  * TODO allow to change password
@@ -18,6 +12,9 @@
  * TODO check types on import
  * TODO sort after insert new card
  * TODO add warn message when import and export!
+ * TODO multilanguage
+ * TODO groups implementation
+ * TODO pc version?
  */
 
 #include "eWallet.h"
@@ -40,6 +37,8 @@ DatabaseManager * dbManager;
 
 eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 {
+	centralWidget = NULL;
+
 	this->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 	connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
 
@@ -67,12 +66,14 @@ void eWallet::orientationChanged(int o) {
 	}
 }
 void eWallet::showList () {
+	qDebug () << "going to showList";
+
 	isAskPassword = false;
 
 	setProperty("FingerScrollable", false);
 	//setContextMenuPolicy(Qt::NoContextMenu);
 	//                         // Central widget and Layout
-	if (!centralWidget) {
+	//if (centralWidget == NULL) {
 		centralWidget = new QWidget(this);
 
 		setContextMenuPolicy(Qt::DefaultContextMenu);
@@ -112,12 +113,15 @@ void eWallet::showList () {
 		hideSearch->hide ();
 
 		centralWidget->setLayout(vboxlayout);
-		setCentralWidget(centralWidget);
+	//}
 
-		createMenu ();
+	createMenu ();
 
-		centralWidget->setFocus ();
-	}
+	qDebug () << "setCentralWidget(centralWidget);";
+	setCentralWidget(centralWidget);
+
+	qDebug () << "setFocus()";
+	centralWidget->setFocus ();
 
 	showTargets (true);
 }
@@ -401,6 +405,8 @@ QPixmap eWallet::getImage (Target * target) {
 }
 void eWallet::showTargets(bool reset)
 {
+	qDebug () << "show Targets " << reset;
+
 	// Clean previous items from the layout
 	fnListWidget->clear();
 
@@ -443,6 +449,8 @@ void eWallet::showTargets(bool reset)
 
 void eWallet::createMenu()
 {
+	qDebug () << "create Menu " << isAskPassword;
+
 	if (isAskPassword) {
 		menuBar()->clear();
 
@@ -613,7 +621,7 @@ void eWallet::viewTarget(Target * rent) {
 	dbManager->getFields(rent);
 
 	if (detailWindow.isNull()) {
-		detailWindow = new DetailWindow(rent, false, this, this);
+		detailWindow = new DetailWindow(rent, false, false, this, this);
 
 		connect(detailWindow, SIGNAL(editTarget(Target*)),
                       this, SLOT(editTarget(Target*)));
@@ -637,7 +645,7 @@ void eWallet::editTarget(Target * rent) {
 	dbManager->getFields(rent);
 
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(rent, true, this, this);
+		detailWindowEdit = new DetailWindow(rent, false, true, this, this);
 //#ifdef Q_WS_MAEMO_5
 		detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
 //#endif
@@ -657,6 +665,9 @@ void eWallet::import() {
 	                "Choose import file",
 	                path,
 	                "Text (*.txt)");
+
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+
 	if (!s.isNull () && !s.isEmpty ()) {
 
 		  QFile file(s);
@@ -685,6 +696,10 @@ void eWallet::import() {
 						  target->name = line.mid(j + 1).trimmed();
 						  break;
 					  case 1:
+						  // TODO check type with existing one!
+						  target->groupName = line.mid(j + 1).trimmed();
+						  break;
+					  case 2:
 						  // TODO check type with existing one!
 						  target->type = line.mid(j + 1).trimmed();
 						  break;
@@ -737,17 +752,19 @@ void eWallet::import() {
 		      }
 		      else {
 		    	  if (target != NULL) {
-		    		  this->_insertTarget(target);
+		    		  this->__insertTarget(target);
 		    	  }
 		    	  target = NULL;
 		    	  i = 0;
 		      }
 
+		      QApplication::instance()->processEvents();
+
 		      //qDebug () << line;
 		    }
 
 			 if (target != NULL) {
-				  this->_insertTarget(target);
+				  this->__insertTarget(target);
 			 }
 		    // Close the file
 		    file.close();
@@ -755,13 +772,14 @@ void eWallet::import() {
 		    showTargets (true);
 		  }
 	}
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 }
 
 void eWallet::newTarget() {
 	//qDebug()<<"new ";
 
 	if (detailWindowEdit.isNull()) {
-		detailWindowEdit = new DetailWindow(NULL, true, this, this);
+		detailWindowEdit = new DetailWindow(NULL, false, true, this, this);
 //#ifdef Q_WS_MAEMO_5
 		detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
 //#endif
@@ -783,6 +801,7 @@ void eWallet::contextMenuEvent (QContextMenuEvent * event) {
 		QMenu menu(this);
 		menu.addAction("View", this, SLOT(_viewcTarget()));
 		menu.addAction("Edit", this, SLOT(_editcTarget()));
+		menu.addAction("New like this", this, SLOT(_newLikeTarget()));
 		menu.addAction("Delete", this, SLOT(_deletecTarget()));
 		menu.exec(event->globalPos());
 	}
@@ -795,6 +814,8 @@ void eWallet::exportData() {
 	                "Choose export file",
 	                path,
 	                "Text (*.txt)");
+
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 	if (!s.isNull () && !s.isEmpty ()) {
 		  QFile file(s);
 
@@ -806,6 +827,7 @@ void eWallet::exportData() {
 				Target * target = list[i];
 
 				t << "Name: " << target->name << "\n";
+				t << "Group Name: " << target->groupName << "\n";
 				t << "Type: " << target->type << "\n";
 
 				dbManager->getFields(target);
@@ -819,12 +841,37 @@ void eWallet::exportData() {
 
 				target->freeFieldList();
 
+				QApplication::instance()->processEvents();
+
 			}
 
 		    // Close the file
 		    file.close();
 		  }
 	}
+	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
+}
+
+void eWallet::_newLikeTarget() {
+	if (fnListWidget->currentRow() >= 0) {
+		Target * target = list.at(fnListWidget->currentRow());
+
+		dbManager->getFields(target);
+
+		if (detailWindowEdit.isNull()) {
+			detailWindowEdit = new DetailWindow(target, true, true, this, this);
+	//#ifdef Q_WS_MAEMO_5
+			detailWindowEdit->setAttribute(Qt::WA_Maemo5StackedWindow);
+	//#endif
+			//detailWindowEdit->showMaximized();
+	        detailWindowEdit->setAttribute(Qt::WA_DeleteOnClose);
+	        connect(detailWindowEdit, SIGNAL(destroyed(QObject*)),
+	                this, SLOT(windowDestroyed(QObject*)));
+	        detailWindowEdit->show();
+			//detailWindow->exec();
+		}
+	}
+	//editTarget(((QFNListItem*)fnListWidget->currentItem())->getSource());
 }
 
 void eWallet::_editcTarget() {
